@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: ZephyrusSettings.py 11936 2020-02-19 07:31:27Z Lavender $
+# $Id: ZephyrusSettings.py 11942 2020-02-19 17:21:00Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-02-19 16:31:27 +0900 (週三, 19 二月 2020) $
-# $Revision: 11936 $
+# $Date: 2020-02-20 02:21:00 +0900 (週四, 20 二月 2020) $
+# $Revision: 11942 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -170,12 +170,12 @@ INSTALLED_APPS = (
     'djangocms_column',
     'filer',
     'easy_thumbnails',
-    'cmsplugin_filer_image',
-    'cmsplugin_filer_file',
-    'cmsplugin_filer_folder',
-    'cmsplugin_filer_teaser',
-    'cmsplugin_filer_utils',
-    'cmsplugin_filer_video',
+    # 'cmsplugin_filer_image',
+    # 'cmsplugin_filer_file',
+    # 'cmsplugin_filer_folder',
+    # 'cmsplugin_filer_teaser',
+    # 'cmsplugin_filer_utils',
+    # 'cmsplugin_filer_video',
     'djangocms_googlemap',
     'djangocms_inherit',
     'djangocms_link',
