@@ -18,7 +18,7 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='MayLikePlugin',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='blog_extension_maylikeplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='blog_extension_maylikeplugin', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                 ('limit', models.PositiveIntegerField(default=6)),
                 ('renderTemplate', models.CharField(default=b'blog_extension/Default.html', max_length=150, verbose_name='Comment Template', blank=True, choices=[(b'blog_extension/Default.html', 'Default')])),
                 ('categories', aldryn_categories.fields.CategoryManyToManyField(to='aldryn_categories.Category', verbose_name='categories', blank=True)),
