@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 12002 2020-03-24 16:46:06Z Trista $
+# $Id: cms_dumpdata.py 12006 2020-03-24 18:55:57Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-03-25 00:46:06 +0800 (週三, 25 三月 2020) $
-# $Revision: 12002 $
+# $Date: 2020-03-25 03:55:57 +0900 (週三, 25 三月 2020) $
+# $Revision: 12006 $
 
 import os
 import sys
@@ -118,12 +118,17 @@ class Command(BaseCommand):
             
 
             path = os.path.join(options['path'])
+            
+            try:
 
-            with open(path, 'w') as f:
-                content = f.write(json.dumps(data))
-            # os.remove('authData.json')
-            # os.remove('treenodeData.json')
-            # os.remove('otherData.json')
+                with open(path, 'w') as f:
+                    content = f.write(json.dumps(data))
+                   
+            except Exception as e:
+                os.remove(path)
+                raise e
+        
+        
             
         finally:
         
@@ -136,7 +141,5 @@ class Command(BaseCommand):
             if os.path.exists('otherData.json'):
                 os.remove('otherData.json')
                 
-            path = os.path.join(options['path'])
-            if os.path.exists(path):
-                os.remove(path)
+            
         
