@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 11671 2019-08-07 04:50:27Z Lavender $
+# $Id: pluginize.py 11840 2020-01-07 13:45:58Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-08-07 12:50:27 +0800 (週三, 07 八月 2019) $
-# $Revision: 11671 $
+# $Date: 2020-01-07 22:45:58 +0900 (週二, 07 一月 2020) $
+# $Revision: 11840 $
 
 import os
 import json
@@ -40,8 +40,8 @@ from filer.models.filemodels import File
 from cms.models.pagemodel import Page
 from cms.models.pluginmodel import CMSPlugin
 from lxml.html import fromstring
-from html5lib import sanitizer
-from html5lib.filters import sanitizer as filtersSanitizer
+# from html5lib import sanitizer
+# from html5lib.filters import sanitizer as filtersSanitizer
 
 from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Zephyrus.boilerplate.management.commands import (
@@ -61,8 +61,8 @@ complexity = 0
 tagList = []
 
 # To fix #2985 
-sanitizer.HTMLSanitizerMixin.acceptable_css_properties = CSS_PROPERTIES
-sanitizer.HTMLSanitizerMixin.allowed_css_properties = CSS_PROPERTIES
+# sanitizer.HTMLSanitizerMixin.acceptable_css_properties = CSS_PROPERTIES
+# sanitizer.HTMLSanitizerMixin.allowed_css_properties = CSS_PROPERTIES
 
 reString = ("^(#[0-9a-f]+|rgb\(\d+%?,\d*%?,?\d*%?\)?|\d{0,2}\.?\d{0,2}"
             "(cm|em|ex|in|mm|pc|pt|px|%|,|\))?)$")
@@ -91,7 +91,7 @@ def sanitize_css(self, style):
 
         return ' '.join(clean)
 
-sanitizer.HTMLSanitizerMixin.sanitize_css = sanitize_css
+# sanitizer.HTMLSanitizerMixin.sanitize_css = sanitize_css
 
 class Attr(object):
     def __init__(self, name, value):
@@ -130,7 +130,6 @@ class Placeholder2(Placeholder):
         from cms.models.placeholdermodel import Placeholder
         from cms.models.pluginmodel import CMSPlugin
         from djangocms_text_ckeditor.models import Text
-        from cmsplugin_filer_image.models import FilerImage
         from djangocms_picture.models import Picture
 
         placeholders = Placeholder.objects.filter(slot=name)
@@ -247,6 +246,7 @@ class Placeholder2(Placeholder):
                                 attributes=imgAttrDict,
                             )                    
                     else:
+                        from cmsplugin_filer_image.models import FilerImage
                         if root.tag == 'a':
                             link = root.get('href')
                             FilerImage.objects.create(
@@ -291,7 +291,6 @@ class Command(BaseCommand):
     def handle(self, language='', *args, **options):
         try:
             from django import template
-            from django.core.urlresolvers import reverse
             from django.contrib.auth.models import AnonymousUser
             
             from sekizai.context import SekizaiContext
