@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12010 2020-03-25 07:40:45Z Lavender $
+# $Id: cms_plugins.py 12011 2020-03-25 11:01:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-25 16:40:45 +0900 (週三, 25 三月 2020) $
-# $Revision: 12010 $
+# $Date: 2020-03-25 20:01:56 +0900 (週三, 25 三月 2020) $
+# $Revision: 12011 $
 
 import re
 import requests
@@ -65,33 +65,33 @@ def getAccessToken():
     # )
     return FacebookSettings.objects.get().accessToken
     
-POPUP_SCRIPTS = '''
+def getAuthorizationMsg():
+    popScript = '''
 <script>
     function popupCallback(str){
-        alert("This is callback:" + str);
+        location.reload(true);
     }
-    function openPopup(){
+    $('#authorization').click(function(){
         var popupWindow = window.open("%s", "popupWindow", "status=1, height=600, width=600, toolbar=0,resizable=0");
         popupWindow.window.focus();
-    }
+    })
 </script>
 ''' % reverse("facebookAuthorizationRedirect")
-    
-def getAuthorizationMsg():
+
     if not getAccessToken():
         accessMessage = _(
             '<p>We are not authorized to read your fan information, please use the following link:</p>'
             '<a href="#" id="authorization">Allow this plugin to read your fan information</a>'
             '<p>If we are not authorized, This will cause restrictions on access to FB fan-specific information '
             '(e.g. filtering function).</p>'
-            ) % reverse("facebookAuthorizationRedirect")
+            )
     else:
         accessMessage = _(
             '<p>We have obtained your fan special authorization and'
             ' can read your fan special information normally</p>'
-            '<a href="#" id="authorization">Re-verify</a>') % reverse("facebookAuthorizationRedirect")
+            '<a href="#" id="authorization">Re-verify</a>')
             
-    return accessMessage + POPUP_SCRIPTS
+    return accessMessage + popScript
         
 def getFanPageId(accessToken, url):
     # get fan page id
@@ -405,7 +405,7 @@ class FacebookPhotoPlugin(CMSPluginBase):
             if albumId:
                 query = "?fields=photos.limit(100){name,images,link}"
                 req = requests.get(
-                    'https://graph.facebook.com/v2.8/%s/%s&access_token=%s' % (
+                    'https://graph.facebook.com/v6.0/%s/%s&access_token=%s' % (
                     albumId, query, accessToken)
                     )
             else:
@@ -419,7 +419,7 @@ class FacebookPhotoPlugin(CMSPluginBase):
                     })
                     return context
                 req = requests.get(
-                    'https://graph.facebook.com/v2.8/%s/%s&access_token=%s' % (
+                    'https://graph.facebook.com/v6.0/%s/%s&access_token=%s' % (
                     fanPageId, query, accessToken)
                 )     
             
