@@ -14,7 +14,7 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='FacebookFan',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_facebookfan', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_facebookfan', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                 ('url', models.URLField()),
                 ('limit', models.IntegerField(default=100)),
             ],
@@ -26,7 +26,7 @@ class Migration(migrations.Migration):
         migrations.CreateModel(
             name='FacebookPhoto',
             fields=[
-                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_facebookphoto', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
+                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_facebookphoto', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                 ('url', models.URLField()),
                 ('limit', models.IntegerField(default=100)),
             ],
