@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11977 2020-03-16 18:37:48Z Lavender $
+# $Id: models.py 12011 2020-03-25 11:01:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-17 03:37:48 +0900 (週二, 17 三月 2020) $
-# $Revision: 11977 $
+# $Date: 2020-03-25 20:01:56 +0900 (週三, 25 三月 2020) $
+# $Revision: 12011 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -28,7 +28,7 @@ class FacebookSettings(SingletonModel):
     accessToken = models.CharField(_('Access token'), max_length=512, blank=True, null=True, default=None)
 
 class FacebookFan(CMSPlugin):
-    url = models.URLField(max_length=400)
+    url = models.URLField(_("Facebook fan page URL"), max_length=400)
     limit = models.PositiveIntegerField(default=0, 
         validators=[MaxValueValidator(20),])
 
@@ -58,7 +58,7 @@ class FacebookFan(CMSPlugin):
         verbose_name_plural = _("Facebook Fan Page")
     
 class FacebookPhoto(CMSPlugin):
-    url = models.URLField(max_length=400)
+    url = models.URLField(_("Facebook fan page album URL"), max_length=400)
     limit = models.PositiveIntegerField(default=0,
         validators=[MaxValueValidator(20),])
     renderTemplate = models.CharField(
