@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11977 2020-03-16 18:37:48Z Lavender $
+# $Id: views.py 12011 2020-03-25 11:01:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-17 02:37:48 +0800 (週二, 17 三月 2020) $
-# $Revision: 11977 $
+# $Date: 2020-03-25 20:01:56 +0900 (週三, 25 三月 2020) $
+# $Revision: 12011 $
 
 import json
 
 import requests
 
-from django.shortcuts import redirect
+from django.shortcuts import redirect, render
 from django.views.generic import View
 from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
@@ -33,7 +33,7 @@ from Zephyrus.facebook import settings as FBSettings
 from Zephyrus.facebook import getCommentURL, getAPIData
 from Zephyrus.facebook.models import APIData, FacebookSettings
 
-def createAuthorizationUrl(request, scope=["manage_pages", "pages_show_list"], state=MANAGE_PAGES_STATE):
+def createAuthorizationURL(request, scope=["manage_pages", "pages_show_list"], state=MANAGE_PAGES_STATE):
     scope = ",".join(scope)
     redirectUrl = "https://%s%s" % (request.META['HTTP_HOST'], reverse("facebookAuthorization"))
     url = ("https://www.facebook.com/v6.0/dialog/oauth?client_id="
@@ -45,7 +45,7 @@ def createAuthorizationUrl(request, scope=["manage_pages", "pages_show_list"], s
     
     return url
     
-def createAccessTokenAPIUrl(request, code):
+def createAccessTokenAPIURL(request, code):
     redirectUrl = "https://%s%s" % (request.META['HTTP_HOST'], reverse("facebookAuthorization"))
     url = ("https://graph.facebook.com/v6.0/oauth/access_token"
            "?client_id=%s&redirect_uri=%s&client_secret=%s&code=%s") % (
@@ -56,7 +56,7 @@ def createAccessTokenAPIUrl(request, code):
 class AuthorizationRedirectView(View):
 
     def get(self, request, *args, **kwargs):
-        return redirect(createAuthorizationUrl(request))
+        return redirect(createAuthorizationURL(request))
     
 
 class FacebookAuthorizationView(View):
@@ -65,19 +65,24 @@ class FacebookAuthorizationView(View):
         if MANAGE_PAGES_STATE == request.GET.get("state"):
             # dealwith auth as access token
             code = request.GET.get("code")
-            url = createAccessTokenAPIUrl(request, code)
-            data = requests.get(url)
-            data = json.loads(data.text)
-            accessToken = data.get("access_token")
+            url = createAccessTokenAPIURL(request, code)
             
-            if accessToken:
-                # save accessToken
-                config, created = FacebookSettings.objects.get_or_create()
-                config.accessToken = accessToken
-                config.save()
-                return HttpResponse(_("<p>Authorization successfully, you can close this page.</p>"))
-            else:
-                return HttpResponse(_("<p>Authorization failed, please try again.</p>"))
+            try:
+                data = requests.get(url)
+                data = json.loads(data.text)
+                accessToken = data.get("access_token")
+                
+                if accessToken:
+                    # save accessToken
+                    config, created = FacebookSettings.objects.get_or_create()
+                    config.accessToken = accessToken
+                    config.save()
+                    msg = _("Authorization successfully, this window will close automatically.")
+                else:
+                    msg = _("Authorization failed, please try again. This window will close automatically.")
+            except Exception as e:
+                msg = _("Authorization failed, please try again. This window will close automatically.")
+            return render(request, "facebook/Authorization.html", {"msg": msg,})
         raise Http404()
    
 if "Zephyrus.comment" in settings.INSTALLED_APPS:
