@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11929 2020-02-17 04:57:08Z Trista $
+# $Id: views.py 11946 2020-02-22 13:22:03Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,18 +12,17 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-02-17 13:57:08 +0900 (週一, 17 二月 2020) $
-# $Revision: 11929 $
+# $Date: 2020-02-22 22:22:03 +0900 (週六, 22 二月 2020) $
+# $Revision: 11946 $
 
 import datetime
 import logging
 import urllib
 import six
-import hashlib
 
 from unidecode import unidecode
 
-from django.shortcuts import redirect, get_object_or_404, render
+from django.shortcuts import redirect, get_object_or_404
 from django.views.generic import View
 from django.core.mail import send_mail
 from django.conf import settings
@@ -34,8 +33,6 @@ from django.contrib import auth
 from django.core.validators import validate_email
 from django.core.exceptions import ValidationError
 from django.template.defaultfilters import slugify
-from django.urls import reverse
-from django.conf import settings
 
 from djangocms_forms.models import FormDefinition
 from djangocms_forms.utils import hashid_to_int
@@ -44,9 +41,6 @@ from djangocms_forms.forms import FormBuilder
 from Zephyrus.landing import ErrorCode
 from Zephyrus.landing.models import Email
 
-from Zephyrus.blog_extension.models import ActionRecord, Action
-from filer.models.filemodels import File
-
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler())
@@ -72,31 +66,6 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
             key = slugify(unidecode(field.label).replace('-', '_'))
             value = form.cleaned_data.get(key, '(no input)')
             dataDict[key] = {'value': value, 'field': field,}
-
-        if 'fileId' in request.POST:
-            fileId = request.POST.get('fileId')
-            targetFile = get_object_or_404(File, pk=fileId)
-            action = get_object_or_404(
-                Action,
-                file=targetFile,
-                formdefinition_ptr_id=landingForm.id
-            )
-            m = hashlib.md5()
-            data = f"{email}{targetFile.original_filename}"
-            m.update(data.encode("utf-8"))
-            token = m.hexdigest()
-            actionRecord, created = ActionRecord.objects.get_or_create(
-                action=action,
-                email=email,
-                url=fromUrl,
-                defaults={'token':token, 'count':0}
-            )
-            if not created:
-                actionRecord.count = actionRecord.count + 1
-            actionRecord.save()
-            link = reverse('showActionFile') + '?key=' + targetFile.sha1
-            fileData = {'link': link, 'token': token}
-
     elif formId:
         formId = hashid_to_int(formId)
         landingForm = get_object_or_404(FormDefinition, pk=formId)
@@ -188,17 +157,11 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                     fail_silently=False
                 )
             else:
-                if fileId:
-                    replaceStr.update(fileData)
-                    mail = get_template('landing/FileVerification.txt')
-                    message = mail.render(replaceStr)
-                else:
-                    mail = Template(landingForm.post_submit_msg)
-                    message = mail.render(Context(replaceStr))
+                mail = Template(landingForm.post_submit_msg)
                 title = landingForm.email_subject
                 send_mail(
                     title,
-                    message,
+                    mail.render(Context(replaceStr)),
                     settings.DEFAULT_FROM_EMAIL,
                     [email.email,],
                     fail_silently=False
@@ -250,14 +213,3 @@ class LandingSocialView(View):
         auth.logout(request)
         return sendAndRedirect(
             request, email, fromUrl, redirectTo, formId=formId)
-
-
-
-def showActionFile(request):
-    key = request.GET.get('key')
-    if request.GET.get('token'):
-        actionRecord = get_object_or_404(ActionRecord, action__file__sha1=key, token=request.GET.get('token'))
-        return redirect(settings.MEDIA_URL + str(actionRecord.action.file.file))
-
-    else:
-        return render(request, 'landing/FileVerification.html', {'key': key})
