@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: 0001_initial.py 11641 2019-06-19 07:33:01Z Lavender $
+# $Id: 0001_initial.py 11984 2020-03-19 12:21:32Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-19 16:33:01 +0900 (週三, 19 六月 2019) $
-# $Revision: 11641 $
+# $Date: 2020-03-19 21:21:32 +0900 (週四, 19 三月 2020) $
+# $Revision: 11984 $
 
 from __future__ import unicode_literals
 
@@ -35,11 +35,10 @@ def moveViewCount(apps, schemaEditor):
     
     URL = apps.get_model('statistics', 'URL')
     for vc in ViewCount.objects.all():
-        url = URL.objects.create(
-            id=vc.id,
+        url, created = URL.objects.get_or_create(
             url=vc.url,
-            viewCount=vc.count,
         )
+        url.viewCount=vc.count
         url.save()
 
 
